/* crlcache.h - LDAP access
 *      Copyright (C) 2002 Klarlvdalens Datakonsult AB
 *
 * This file is part of DirMngr.
 *
 * DirMngr is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * DirMngr is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */

#ifndef CRLCACHE_H
#define CRLCACHE_H

#include <gdbm.h>
#include <time.h>
#include <ksba.h>

/* Change this whenever the format changes */
#define DBCONTENTSVERSION "DirMngr contents file v0.2"
#define DBDIR "cache"
#define DBCONTENTSFILE "dbcontents"


enum CrlCacheReturn { CRL_CACHE_VALID, CRL_CACHE_INVALID, CRL_CACHE_DONTKNOW };
enum CrlSigReturn { CRL_SIG_OK = 0, CRL_SIG_NOT_OK, CRL_TOO_OLD, CRL_SIG_ERROR };

typedef struct CrlCacheEntry_s {
  char* issuer_hash;
  time_t this_update;
  time_t next_update;
  GDBM_FILE dbf;
  struct CrlCacheEntry_s* next;
} CrlCacheEntry;

typedef struct CrlCache_s {
  CrlCacheEntry* entries;
} CrlCache;

CrlCache*      crl_cache_init(void);
void           crl_cache_deinit( CrlCache* cptr );
enum CrlCacheReturn crl_cache_isvalid( CrlCache* cptr, const char* issuer_hash, const char* cert_id );

int crl_cache_insert( CrlCache* cptr, const char* value, size_t valuelen );

/*int crl_check_sig( KsbaCRL crl, KsbaCert issuer_cert );*/

#endif /* CRLCACHE_H */
